@@ -1,9 +1,10 @@
 use crate::{repr::*, *};
-use alloc::string::ToString;
+use alloc::string::{String, ToString};
 use core::{
-    fmt::{Debug, Formatter, Result as FmtResult},
-    hash::Hash,
+    fmt::{Debug, Formatter},
+    hash::{Hash, Hasher},
     iter::FromIterator,
+    marker::PhantomData,
     ops::Index,
     str::FromStr,
 };
@@ -63,9 +64,9 @@ pub type NodeArc = Node<ArcRepr>;
 /// use yaml_peg::{NodeRc, Yaml};
 ///
 /// let mut s = HashSet::new();
-/// s.insert(NodeRc::new(Yaml::from("a"), 0, "", ""));
-/// s.insert(NodeRc::new("a", 1, "my-tag", ""));
-/// s.insert(NodeRc::new("a", 2, "", "my-anchor"));
+/// s.insert(NodeRc::new(Yaml::from("a"), 0, ""));
+/// s.insert(NodeRc::new("a", 1, "my-tag"));
+/// s.insert(NodeRc::new("a", 2, ""));
 /// assert_eq!(s.len(), 1);
 /// ```
 ///
@@ -118,54 +119,56 @@ pub type NodeArc = Node<ArcRepr>;
 /// }
 /// ```
 ///
-/// # Anchor
-///
-/// The anchors can be infer from [`Anchor`], and attach with [`Node::as_anchor`] method.
-///
 /// # Clone
 ///
-/// Since the YAML data is wrapped by reference counter [`alloc::rc::Rc`] and [`alloc::sync::Arc`],
-/// cloning node just increase the reference counter,
-/// the entire data structure are still shared together.
+/// Since the YAML data is wrapped by reference counter [`alloc::rc::Rc`]/[`alloc::sync::Arc`],
+/// cloned nodes are still shared together, just like Python or JavaScript.
+/// Please see the [`Node::rc_ref`]/[`Node::yaml`]/[`Node::clone_yaml`] methods for details.
 ///
-/// ```
-/// use std::rc::Rc;
-/// use yaml_peg::node;
-///
-/// let a = node!("a");
-/// {
-///     let b = a.clone();
-///     assert_eq!(2, Rc::strong_count(&b));
-/// }
-/// assert_eq!(1, Rc::strong_count(&a));
-/// ```
-///
-/// If you want to copy data, please get the data first.
-#[derive(Hash, Eq, PartialEq, Clone)]
-pub struct Node<R: Repr = RcRepr>(pub(crate) R);
+/// If you still want to copy data, use [`From`]/[`Into`] or serialize them to your custom type.
+pub struct Node<R: Repr> {
+    pos: u64,
+    tag: String,
+    yaml: R::Ty,
+    _marker: PhantomData<R>,
+}
 
 impl<R: Repr> Node<R> {
     /// Create node from YAML data.
-    pub fn new<Y>(yaml: Y, pos: u64, tag: &str, anchor: &str) -> Self
-    where
-        Y: Into<Yaml<R>>,
-    {
-        let yaml = yaml.into();
-        Self(R::repr(yaml, pos, tag.to_string(), anchor.to_string()))
+    pub fn new(yaml: impl Into<Yaml<R>>, pos: u64, tag: impl ToString) -> Self {
+        Self::new_repr(R::repr(yaml.into()), pos, tag)
+    }
+
+    /// Create from a representation.
+    pub fn new_repr(yaml: R::Ty, pos: u64, tag: impl ToString) -> Self {
+        Self {
+            yaml,
+            pos,
+            tag: tag.to_string(),
+            _marker: PhantomData,
+        }
+    }
+
+    /// Set from existing YAML data.
+    pub fn set_yaml(&mut self, yaml: impl Into<Yaml<R>>) {
+        self.set_repr(R::repr(yaml.into()));
+    }
+
+    /// Set from existing YAML representation.
+    pub fn set_repr(&mut self, yaml: R::Ty) {
+        self.yaml = yaml;
     }
 
     /// Document position.
-    #[inline(always)]
     pub fn pos(&self) -> u64 {
-        self.0.pos
+        self.pos
     }
 
     /// Tag. If the tag is not specified, returns a default tag from core schema.
     ///
     /// Anchor has no tag.
-    #[inline(always)]
     pub fn tag(&self) -> &str {
-        match self.0.tag.as_str() {
+        match self.tag.as_str() {
             "" => match self.yaml() {
                 Yaml::Null => concat!(parser::tag_prefix!(), "null"),
                 Yaml::Bool(_) => concat!(parser::tag_prefix!(), "bool"),
@@ -180,16 +183,31 @@ impl<R: Repr> Node<R> {
         }
     }
 
-    /// Anchor reference.
-    #[inline(always)]
-    pub fn anchor(&self) -> &str {
-        &self.0.anchor
+    /// YAML data.
+    pub fn yaml(&self) -> &Yaml<R> {
+        &self.yaml
     }
 
-    /// YAML data.
-    #[inline(always)]
-    pub fn yaml(&self) -> &Yaml<R> {
-        &self.0.yaml
+    /// Clone YAML repr.
+    pub fn clone_yaml(&self) -> R::Ty {
+        self.yaml.clone()
+    }
+
+    /// As reference for the underlying reference counter.
+    ///
+    /// ```
+    /// use std::rc::Rc;
+    /// use yaml_peg::node;
+    ///
+    /// let a = node!("a");
+    /// {
+    ///     let b = a.clone();
+    ///     assert_eq!(2, Rc::strong_count(b.rc_ref()));
+    /// }
+    /// assert_eq!(1, Rc::strong_count(a.rc_ref()));
+    /// ```
+    pub fn rc_ref(&self) -> &R::Ty {
+        &self.yaml
     }
 
     /// Check the value is null.
@@ -281,25 +299,6 @@ impl<R: Repr> Node<R> {
         }
     }
 
-    /// Infer an anchor with anchor visitor.
-    ///
-    /// If the node is not a anchor, or the anchor does not exist, the original node is returned.
-    /// Since the anchor type is invalid except for this method, missing anchor will still return an error.
-    ///
-    /// ```
-    /// use yaml_peg::{node, anchors};
-    ///
-    /// let node_a = node!(*"a");
-    /// let v = anchors!["a" => 20.];
-    /// assert_eq!(20., node_a.as_anchor(&v).as_float().unwrap());
-    /// ```
-    pub fn as_anchor<'a, 'b: 'a>(&'a self, v: &'b Anchor<R>) -> &'a Self {
-        match self.yaml() {
-            Yaml::Alias(s) if v.contains_key(s) => v.get(s).unwrap(),
-            _ => self,
-        }
-    }
-
     as_method! {
         /// Convert to sequence.
         ///
@@ -401,7 +400,7 @@ impl<R: Repr> Node<R> {
     ) -> Result<Ret, u64>
     where
         Y: Into<Self>,
-        F: Fn(&'a Self) -> Result<Ret, u64>,
+        F: FnOnce(&'a Self) -> Result<Ret, u64>,
     {
         if let Yaml::Map(m) = self.yaml() {
             if let Some(n) = m.get(&key.into()) {
@@ -435,47 +434,43 @@ impl<R: Repr> Node<R> {
             Err(self.pos())
         }
     }
-
-    /// Replace the anchor insertion recursively.
-    /// Return `None` if the anchor is not found.
-    ///
-    /// If the anchor contains a self-loop, `Yaml::Anchor` will be left.
-    ///
-    /// See also [`Anchor::resolve`].
-    pub fn replace_anchor(&self, visitor: &Anchor<R>) -> Result<Self, InvalidAnchor> {
-        match self.yaml() {
-            Yaml::Alias(anchor) => visitor.get(anchor).cloned().ok_or_else(|| InvalidAnchor {
-                anchor: anchor.clone(),
-            }),
-            Yaml::Seq(seq) => seq
-                .iter()
-                .map(|node| node.replace_anchor(visitor))
-                .collect::<Result<Seq<_>, _>>()
-                .map(|seq| self.new_with_yaml(Yaml::Seq(seq))),
-            Yaml::Map(map) => map
-                .iter()
-                .map(|(k, v)| {
-                    k.replace_anchor(visitor)
-                        .and_then(|k| Ok((k, v.replace_anchor(visitor)?)))
-                })
-                .collect::<Result<Map<_>, _>>()
-                .map(|map| self.new_with_yaml(Yaml::Map(map))),
-            _ => Ok(self.clone()),
-        }
-    }
-
-    /// Create a node with original information.
-    pub fn new_with_yaml(&self, yaml: Yaml<R>) -> Self {
-        Self::new(yaml, self.pos(), self.tag(), self.anchor())
-    }
 }
 
 impl<R: Repr> Debug for Node<R> {
-    fn fmt(&self, f: &mut Formatter) -> FmtResult {
-        f.write_fmt(format_args!("Node{:?}", &self.0))
+    fn fmt(&self, f: &mut Formatter<'_>) -> core::fmt::Result {
+        f.debug_struct("Node")
+            .field("pos", &self.pos)
+            .field("tag", &self.tag)
+            .field("yaml", &self.yaml)
+            .finish()
     }
 }
 
+impl<R: Repr> Clone for Node<R> {
+    fn clone(&self) -> Self {
+        Self {
+            pos: self.pos,
+            tag: self.tag.clone(),
+            yaml: self.clone_yaml(),
+            _marker: PhantomData,
+        }
+    }
+}
+
+impl<R: Repr> Hash for Node<R> {
+    fn hash<H: Hasher>(&self, state: &mut H) {
+        self.yaml.hash(state)
+    }
+}
+
+impl<R: Repr> PartialEq for Node<R> {
+    fn eq(&self, rhs: &Self) -> bool {
+        self.yaml.eq(&rhs.yaml)
+    }
+}
+
+impl<R: Repr> Eq for Node<R> {}
+
 /// Indicator of the node use to index the sequence position.
 pub struct Ind(pub usize);
 
@@ -514,7 +509,7 @@ where
     Y: Into<Yaml<R>>,
 {
     fn from(yaml: Y) -> Self {
-        Self::new(yaml, 0, "", "")
+        Self::new(yaml, 0, "")
     }
 }
 
